Version 4.00 Spam Action rule file bug??

Julian Field mailscanner at ecs.soton.ac.uk
Tue Sep 24 10:14:00 IST 2002


Try this patch for Message.pm. If it solves the problem it'll be in the
next V4 release.
And can I take this opportunity to thank all of you for helping me debug V4.
With about 100 configuration options, it's very hard for me to test *every*
combination :-(


--- Message.pm.old      Tue Sep 24 10:23:21 2002
+++ Message.pm  Tue Sep 24 10:23:59 2002
@@ -396,8 +396,9 @@
    # Now we are left with deliver, bounce, delete and store.
    #print STDERR "Archive places are " . join(',', keys %actions) . "\n";

-  # Store and deliver over-ride delete
-  delete $actions{'delete'} if $actions{'store'} || $actions{'deliver'};
+  # Store, deliver and forward over-ride delete
+  delete $actions{'delete'} if $actions{'store'} || $actions{'deliver'} ||
+                               $actions{'forward'};

    MailScanner::Log::InfoLog("Spam Actions: message %s actions are %s",
                              $this->{id}, join(',', keys %actions));


At 03:50 24/09/2002, you wrote:
>If I set spam action to a rule file and set the rule similar to below
>To:     user at domain.com forward spam at domain.com
>It's forwarded
>
>If I set it to
>To:     user at domain.com bounce forward spam at domain.com
>It bounced and forwarded.
>
>If I set to
>To:     user at domain.com bounce delete forward spam at domain.com
>Then I get RBL Check ORDB-RBL timed out and was killed, consecutive
>failure 1 of 7 at MailScanner/RBLs.pm line 192  On the console and this
>in the log
>Sep 23 22:40:09 apollo.med.wayne.edu MailScanner[13257]: RBL Check
>ORDB-RBL timed out and was killed, consecutive failure 1 of 7
>Amd all I get is the bounce.
>
>If I set the rule to
>To:     user at domain.com bounce delete
>Then I get a bounce and the deletion as expected.
>
>If I set to
>To:     user at domain.com delete forward spam at domain.com
>Then the message is just deleted.
>
>So it almost seems that delete and forward options can't be used
>together.
>
>-=Bobby

--
Julian Field                Teaching Systems Manager
jkf at ecs.soton.ac.uk         Dept. of Electronics & Computer Science
Tel. 023 8059 2817          University of Southampton
                             Southampton SO17 1BJ



More information about the MailScanner mailing list